@@ -1,10 +1,13 @@
 from typing import List, Tuple, Union, Optional
 from foundry_sdk.db_mgmt import SQLDatabase
 
-def retrieve_data(db: SQLDatabase, table: str, columns: Union[str, List[str]], condition: Optional[str] = None) -> List[Tuple]:
+
+def retrieve_data(
+    db: SQLDatabase, table: str, columns: Union[str, List[str]], condition: Optional[str] = None
+) -> List[Tuple]:
     """
     Retrieve data from a table in the database.
-    
+
     Ensures column names are enclosed in double quotes for PostgreSQL,
     unless columns == "*", in which case it is used as-is.
     Allows single column name as a string or multiple as a list.
